%define Build_gcc3	1

%define upstream_release 2
Summary: A system integrity assessment tool.
Name: tripwire
Version: 2.3.1
Release: 17.2.legacy.9
License: GNU General Public License
Group:   Applications/System
Source0: http://download.sourceforge.net/tripwire/tripwire-%{version}-%{upstream_release}.tar.gz
Source1: tripwire.cron
Source2: tripwire.txt
Source3: tripwire.gif
Source4: twcfg.txt.in
Source5: twinstall.sh.in
Source6: twpol.txt.in
Source7: README.RPM
URL: http://www.tripwire.org/
Requires: sed, grep >= 2.3, gzip, tar, gawk
BuildRoot: %{_tmppath}/%{name}-%{version}-root

# Tripwire is NOT 64bit clean, nor endian clean, and only works properly
# on x86 architecture. The open source code doesn't seem to be maintained,
# so this is probably unlikely to change.  We exclude non x86 arches.
ExclusiveArch: %{ix86}

Patch0: tripwire-2.3.0-50-rfc822.patch
Patch1: tripwire-2.3.1-2-fhs.patch
Patch2: tripwire-2.3.1-gcc3.patch
Patch3: tripwire-jbj.patch
Patch4: tripwire-mkstemp.patch
Patch5: tripwire-2.3.1-2-formatstring.patch

%description
Tripwire is a very valuable security tool for Linux systems, if it is
installed to a clean system. Tripwire should be installed right after
the OS installation, and before you have connected your system to a
network (i.e., before any possibility exists that someone could alter
files on your system).

When Tripwire is initially set up, it creates a database that records
certain file information. Then when it is run, it compares a
designated set of files and directories to the information stored in
the database. Added or deleted files are flagged and reported, as are
any files that have changed from their previously recorded state in
the database. When Tripwire is run against system files on a regular
basis, any file changes will be spotted when Tripwire is run.
Tripwire will report the changes, which will give system
administrators a clue that they need to enact damage control measures
immediately if certain files have been altered.

After installing this package, run /etc/tripwire/twinstall.sh to
generate cryptographic keys and run tripwire --init to initialize the
database.

%prep
%setup -q -n %{name}-%{version}-%{upstream_release}
cp $RPM_SOURCE_DIR/tripwire.txt quickstart.txt
cp $RPM_SOURCE_DIR/tripwire.gif quickstart.gif

%patch0 -p1 -b .rfc822
%patch1 -p1 -b .fhs
%if %{Build_gcc3}
%patch2 -p1 -b .gcc3
%endif
%patch3 -p1 -b .jbj
%patch4 -p1 -b .mkstemp
%patch5 -p1 -b .formatstring

%build
cd src
#make distclean

%if %{Build_gcc3}
rm -rf STLport*
touch STLport_r STLport_d
%endif

# Do not parallelize this with _smp_flags or -j
make release RPM_OPT_FLAGS="$RPM_OPT_FLAGS"

%install
rm -fr ${RPM_BUILD_ROOT}

# Install the binaries.
mkdir -p ${RPM_BUILD_ROOT}%{_sbindir}
install -m755 bin/*/siggen   ${RPM_BUILD_ROOT}%{_sbindir}
install -m755 bin/*/tripwire ${RPM_BUILD_ROOT}%{_sbindir}
install -m755 bin/*/twadmin  ${RPM_BUILD_ROOT}%{_sbindir}
install -m755 bin/*/twprint  ${RPM_BUILD_ROOT}%{_sbindir}

# Install the man pages.
mkdir -p ${RPM_BUILD_ROOT}%{_mandir}/{man4,man5,man8}
install -m644 man/man4/*.4 ${RPM_BUILD_ROOT}%{_mandir}/man4/
install -m644 man/man5/*.5 ${RPM_BUILD_ROOT}%{_mandir}/man5/
install -m644 man/man8/*.8 ${RPM_BUILD_ROOT}%{_mandir}/man8/

# Install configuration information.
mkdir -p ${RPM_BUILD_ROOT}/etc/tripwire
for infile in twinstall.sh twpol.txt twcfg.txt ; do
	cat $RPM_SOURCE_DIR/${infile}.in |\
	sed -e 's|@sbindir@|%{_sbindir}|g' |\
	sed -e 's|@vardir@|%{_var}|g' >\
	${RPM_BUILD_ROOT}/etc/tripwire/${infile}
done

# Create the reports directory.
install -d -m700 ${RPM_BUILD_ROOT}%{_var}/lib/tripwire/report

# Install the cron job.
install -d -m755 ${RPM_BUILD_ROOT}/etc/cron.daily
install -m755 $RPM_SOURCE_DIR/tripwire.cron ${RPM_BUILD_ROOT}/etc/cron.daily/tripwire-check

# Fix permissions on documentation files.
cp $RPM_SOURCE_DIR/README.RPM .
chmod 644 README Release_Notes ChangeLog COPYING TRADEMARK quickstart.gif quickstart.txt README.RPM

%clean
rm -fr ${RPM_BUILD_ROOT}

%files
%defattr(-,root,root)
%doc      README Release_Notes ChangeLog COPYING TRADEMARK quickstart.gif quickstart.txt README.RPM policy/policyguide.txt
%attr(0755,root,root) %dir /etc/tripwire
%attr(0755,root,root) /etc/tripwire/twinstall.sh
%attr(0644,root,root) %config(noreplace) /etc/tripwire/twcfg.txt
%attr(0644,root,root) %config(noreplace) /etc/tripwire/twpol.txt
%attr(0755,root,root) %config(noreplace) /etc/cron.daily/tripwire-check
%attr(0755,root,root) %dir /var/lib/tripwire
%attr(0755,root,root) %dir /var/lib/tripwire/report
%attr(0644,root,root) %{_mandir}/*/*
%attr(0755,root,root) %{_sbindir}/*

%changelog
* Sat Oct  9 2004 Marc Deslauriers <marcdeslauriers@videotron.ca> 2.3.1-17.2.legacy.9
- Removed duplicate Patch4 entry

* Sun Oct  4 2004 Marc Deslauriers <marcdeslauriers@videotron.ca> 2.3.1-17.1.legacy.9
- Removed gcc-c++ BuildRequires
- Downgraded release number so we don't break the upgrade cycle to fc1

* Tue Jun 15 2004 Jesse Keating <jkeating@j2solutions.net> 2.3.1-20.legacy.9
- Added gcc-c++
- Altered version for 7.x/9 independence.

* Fri Jun  4 2004 Marc Deslauriers <marcdeslauriers@videotron.ca> 2.3.1-19.legacy
- Added patch for format string vulnerability (FL #1719)

* Wed Jan 22 2003 Tim Powers <timp@redhat.com>
- rebuilt

* Sat Nov 16 2002 Jeff Johnson <jbj@redhat.com> 2.3.1-16
- rebuild from cvs.
- comment out debug messages to achieve compilation.
- include policyguide.txt (#72259).
- use mkstemp, not mktemp.

* Fri Aug 02 2002 Mike A. Harris <mharris@redhat.com> 2.3.1-14
- Modified default sample twpol file to remove bogus warnings (#70502)

* Fri Jun 21 2002 Tim Powers <timp@redhat.com> 2.3.1-13
- automated rebuild

* Sun May 26 2002 Tim Powers <timp@redhat.com> 2.3.1-12
- automated rebuild

* Wed May 22 2002 Mike A. Harris <mharris@redhat.com> 2.3.1-11
- Rebuilt in new build environment with gcc 3.1

* Tue Feb 26 2002 Mike A. Harris <mharris@redhat.com> 2.3.1-9
- Conditionalized gcc3 patch
- Added back the ExclusiveArch that is required but disappeared somewhere along
  the line.
- Rebuild in new build environment

* Thu Jan 31 2002 Mike A. Harris <mharris@redhat.com> 2.3.1-7
- Bump release and rebuild in new environment.
- (Elliot Lee) Add patch to make it build with gcc3.

* Thu Aug  9 2001 Nalin Dahyabhai <nalin@redhat.com> 2.3.1-5
- define USE_FHS when USES_FHS is defined, so that the database winds up
  in the right directory (#51332)
- update default twpol file to include files recently-added to the full
  installation tree

* Tue Jul 17 2001 Mike A. Harris <mharris@redhat.com> 2.3.1-4
- Applied bugfix for (#47276) to make tripwire email RFC822 compliant, using
  patch in bugreport from Michael Schwendt <mschwendt@yahoo.com>

* Tue Jul 10 2001 Mike A. Harris <mharris@redhat.com> 2.3.1-3
- Made package own dir /var/lib/tripwire
 
* Mon Jun 25 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to 2.3.1-2

* Thu Mar  1 2001 Bill Nottingham <notting@redhat.com>
- rebuild, fix defattr. Weird.

* Tue Feb 27 2001 Nalin Dahyabhai <nalin@redhat.com>
- refresh from upstream
- modify the default policy to match the current tree more closely (#28744)
- make the text files 0644, not 0755
- defattr for the sake of the docs

* Wed Sep 20 2000 Nalin Dahyabhai <nalin@redhat.com>
- change exclusivearch: i386 to exclusivearch: %%{ix86} (#17759)

* Wed Aug 23 2000 Than Ngo <than@redhat.com>
- remove copyleft information in specfile (Bug #16765)

* Tue Aug 22 2000 Nalin Dahyabhai <nalin@redhat.com>
- remove duplicate source files
- sync up description with specspo

* Fri Aug 4 2000 Than Ngo <than@redhat.de>
- remove Vendor and Distribution from specfile (Bug #15246)

* Fri Aug 4 2000 Than Ngo <than@redhat.de>
- starts tripwire --check if it was configured before. (Bug #15384)

* Fri Aug 4 2000 Nalin Dahyabhai <nalin@redhat.com>
- fix sense of checking for the database's existence in the cron job
- actually include twinstall.sh, twcfg.txt, twpol.txt

* Thu Aug 3 2000 Than Ngo <than@redhat.de>
- permission fix (bug #15246)

* Mon Jul 31 2000 Nalin Dahyabhai <nalin@redhat.com>
- add quickstart docs (Ed)
- tweak description text (Ed)

* Thu Jul 20 2000 Nalin Dahyabhai <nalin@redhat.com>
- update .spec file to follow RPM conventions
- add tripwire --check to cron.daily

